@@ -72,9 +72,10 @@ else
 end
 
 if /cygwin|mingw/ =~ RUBY_PLATFORM
-   have_library("narray") || raise("ERROR: narray library is not found")
+   have_library("narray") || raise("ERROR: narray import library is not found")
    if gtkversion == "2"
-     $LOCAL_LIBS += "- lruby-glib2"
+      have_library("ruby-glib2") || 
+                 raise("ERROR: ruby-glib2 import library is not found")
    end
 end
 
